@@ -119,6 +119,7 @@ MainWindow::MainWindow(QObject *parent)
 , m_appIcon(":/qgv.png")
 , m_systrayIcon(NULL)
 , m_ignoreCbInboxChange(false)
+, m_logMessageMutex(QMutex::Recursive)
 #ifdef DBUS_API
 , apiCall(this)
 , apiText(this)
@@ -296,8 +297,18 @@ MainWindow::init()
     d->ui->actionFind->setEnabled (false);
     d->ui->tabWidget->setCurrentIndex (0);
 
+    // Before the user logs in, all other tabs ought to be disabled.
+    d->ui->dialTab->setEnabled (false);
+    d->ui->contactsTab->setEnabled (false);
+    d->ui->inboxTab->setEnabled (false);
+
     // Fake an event in the event loop
     QTimer::singleShot (1, this, SLOT(onInitDone()));
+
+    connect(&m_logMessageTimer, SIGNAL(timeout()),
+            this, SLOT(onLogMessagesTimer()));
+    m_logMessageTimer.setSingleShot (true);
+    m_logMessageTimer.start (10);
 }//MainWindow::init
 
 void
@@ -437,6 +448,11 @@ MainWindow::uiLoginDone(int status, const QString &errStr)
 {
     do {
         if (ATTS_SUCCESS == status) {
+            // Enable tabs on successful login
+            d->ui->dialTab->setEnabled (true);
+            d->ui->contactsTab->setEnabled (true);
+            d->ui->inboxTab->setEnabled (true);
+
             d->ui->statusBar->showMessage ("Login successful", SHOW_5SEC);
             break;
         }
@@ -819,12 +835,35 @@ MainWindow::onCbNumDoModify(int index)
 void
 MainWindow::uiShowStatusMessage(const QString &msg, quint64 millisec)
 {
-    d->ui->statusBar->showMessage (msg, millisec);
+    QMutexLocker l(&m_logMessageMutex);
+    LogMessage m;
+    m.message = msg;
+    m.milli = millisec;
+    m_logMessages.append (m);
 }//MainWindow::uiShowStatusMessage
 
+void
+MainWindow::onLogMessagesTimer()
+{
+    QMutexLocker l(&m_logMessageMutex);
+    quint32 next = 2000;
+
+    if (m_logMessages.count ()) {
+        LogMessage m = m_logMessages.last ();
+        d->ui->statusBar->showMessage (m.message, m.milli);
+        m_logMessages.clear ();
+        next = 100;
+    }
+
+    m_logMessageTimer.start (next);
+}//MainWindow::onLogMessagesTimer
+
 void
 MainWindow::uiClearStatusMessage()
 {
+    QMutexLocker l(&m_logMessageMutex);
+    m_logMessages.clear ();
+
     d->ui->statusBar->clearMessage ();
 }//MainWindow::uiClearStatusMessage
 
