@@ -25,10 +25,19 @@ Contact: yuvraaj@gmail.com
 #include "global.h"
 #include "IMainWindow.h"
 
+#ifdef DBUS_API
+#include "DBusApi.h"
+#endif
+
 class MainWindowPrivate;
 class QSystemTrayIcon;
 class QWebView;
 
+struct LogMessage {
+    QString message;
+    quint64 milli;
+};
+
 class MainWindow : public IMainWindow
 {
     Q_OBJECT
@@ -112,6 +121,8 @@ protected slots:
     void onSbContactsFreqChanged(int val);
     void onSbInboxFreqChanged(int val);
 
+    void onLogMessagesTimer();
+
 private:
     MainWindowPrivate *d;
 
@@ -122,6 +133,22 @@ private:
 
     bool m_ignoreCbInboxChange;
 
+    QMutex      m_logMessageMutex;
+    QVector <LogMessage> m_logMessages;
+    QTimer      m_logMessageTimer;
+
+#ifdef DBUS_API
+protected slots:
+    bool initDBus();
+    void onSigShow();
+
+protected:
+    QGVDBusCallApi      apiCall;
+    QGVDBusTextApi      apiText;
+    QGVDBusSettingsApi  apiSettings;
+    QGVDBusUiApi        apiUi;
+#endif
+
     friend class VmailDialog;
 };
 
